import Vue from 'vue'

import VueRouter from 'vue-router'
import Cookies from 'js-cookie'
import Element from 'element-ui'
import '@/assets/iconfont/iconfont.css';  //阿里矢量库
import './assets/styles/element/element-variables.scss'
import '@/assets/styles/index.scss'
import '@/utils/browser_patch'
import App from './App'
import store from './store'
import router from './router'
import directive from './directive'
import { download,downloadGet,downloadPost,downloadUrl } from '@/utils/request'
import hasPermiDom from './directive/permission/hasPermiDom'
import './assets/icons'
import './permission'
import cal from '@/utils/calculation';
import { getConfigKey,getDicts } from "@/api/commonality/noPermission";
import { parseTime, timeToTimestamp, resetForm, addDateRange, selectDictLabel, selectDictLabels,
        handleTree, spaceJudgment, spaceJudgmentHTML, isNum, urlJudge, uploadUrl,
        judgmentNetworkReturnAddress,versionField, clickCopy } from "@/utils/ruoyi";
import Pagination from "@/components/Pagination";
// 自定义表格工具组件
import RightToolbar from "@/components/RightToolbar"
// 富文本组件
import Editor from "@/components/Editor"
import wangEditor from "@/components/wangEditor"
import UEditor from "@/components/UEditor"
// 文件上传组件
import FileUpload from "@/components/FileUpload"
// 图片上传组件
import ImageUpload from "@/components/ImageUpload"
// 字典标签组件
import DictTag from '@/components/DictTag'
// 头部标签组件
import VueMeta from 'vue-meta'

//全屏组件
import dataV from '@jiaminghi/data-view'
//echarts
import echarts from 'echarts'
//文件分片
import uploader from 'vue-simple-uploader'

import VueCropper from 'vue-cropper'
Vue.use(VueCropper)

//echarts
Vue.prototype.$echarts = echarts
// 全局方法挂载
Vue.prototype.cal = cal
Vue.prototype.getDicts = getDicts
Vue.prototype.getConfigKey = getConfigKey
Vue.prototype.parseTime = parseTime
Vue.prototype.timeToTimestamp = timeToTimestamp
Vue.prototype.resetForm = resetForm
Vue.prototype.addDateRange = addDateRange
Vue.prototype.selectDictLabel = selectDictLabel
Vue.prototype.selectDictLabels = selectDictLabels
Vue.prototype.download = download
Vue.prototype.downloadGet = downloadGet
Vue.prototype.downloadPost = downloadPost
Vue.prototype.downloadUrl = downloadUrl
Vue.prototype.uploadUrl = uploadUrl
Vue.prototype.versionField = versionField
Vue.prototype.clickCopy = clickCopy
Vue.prototype.hasPermiDom = hasPermiDom.hasPermiDom
Vue.prototype.handleTree = handleTree
Vue.prototype.spaceJudgment = spaceJudgment
Vue.prototype.spaceJudgmentHTML = spaceJudgmentHTML
Vue.prototype.isNum = isNum
Vue.prototype.urlJudge = urlJudge
Vue.prototype.judgmentNetworkReturnAddress = judgmentNetworkReturnAddress

Vue.prototype.msgSuccess = function (msg) {
  this.$message({ showClose: true, message: msg, type: "success", offset:100 });
}

Vue.prototype.msgError = function (msg) {
  this.$message({ showClose: true, message: msg, type: "error", offset:100 });
}

Vue.prototype.msgInfo = function (msg) {
  this.$message.info(msg);
}

// 全局组件挂载
Vue.component('DictTag', DictTag)
Vue.component('Pagination', Pagination)
Vue.component('RightToolbar', RightToolbar)
Vue.component('Editor', Editor)
Vue.component('wangEditor', wangEditor)
Vue.component('UEditor', UEditor)
Vue.component('FileUpload', FileUpload)
Vue.component('ImageUpload', ImageUpload)

Vue.use(directive)
Vue.use(VueMeta)
Vue.use(uploader)
//全屏组件
Vue.use(dataV)

/**
 * If you don't want to use mock-server
 * you want to use MockJs for mock api
 * you can execute: mockXHR()
 *
 * Currently MockJs will be used in the production environment,
 * please remove it before going online! ! !
 */

Vue.use(Element, {
  size: Cookies.get('size') || 'medium' // set element-ui default size
})

Vue.config.productionTip = false

// 避免路由冗余导航
const originalPush = VueRouter.prototype.push
VueRouter.prototype.push = function push(location) {
  return originalPush.call(this, location).catch(err => err)
}
const originalReplace = VueRouter.prototype.replace
VueRouter.prototype.replace = function replace(location) {
  return originalReplace.call(this, location).catch(err => err)
}
new Vue({
  el: '#app',
  router,
  store,
  render: h => h(App)
})
